import os
from PIL import Image

def jpg2png(imagePath, newImagePath = None):
    try:
        if newImagePath == None:
            if ".JPG" in imagePath:
                newImagePath = os.path.normpath(imagePath).replace(".JPG", "")+".png"
            elif ".jpg" in imagePath:
                newImagePath = os.path.normpath(imagePath).replace(".jpg", "")+".png"
        else:
            newImagePath = os.path.dirname(imagePath)+"\\"+newImagePath+".png"
        img = Image.open(imagePath).convert("RGB")
        img.save(newImagePath, "png")
    except Exception as e:
        print("Exception: " + str(type(e)) +" "+ str(e))
        print("1. Check the File Extension.")
        print("2. Check the Directory you entered.")


import os
from PIL import Image

def png2ico(imagePath, newImagePath = None):
    try:
        if newImagePath == None:
            if ".PNG" in imagePath:
                newImagePath = os.path.normpath(imagePath).replace(".PNG", "")+".ico"
            elif ".png" in imagePath:
                newImagePath = os.path.normpath(imagePath).replace(".png", "")+".ico"
        else:
            newImagePath = os.path.dirname(imagePath)+"\\"+newImagePath+".ico"
        img = Image.open(imagePath)
        img.save(newImagePath, "ico")
    except Exception as e:
        print("Exception: " + str(type(e)) +" "+ str(e))
        print("1. Check the File Extension.")
        print("2. Check the Directory you entered.")


import os
import PyPDF2
import pyttsx3

def pdf2audio(pdfPath, fileName = None, gen = "male"):
    try:
        filePath = os.path.dirname(pdfPath)+"\\output.mp3" if fileName == None else os.path.dirname(pdfPath)+ "\\" + fileName + ".mp3"
        pdfReader = PyPDF2.PdfFileReader(open(pdfPath, 'rb'))
        gender = 0 if gen.lower() == "male" else 1 if gen.lower() == "female" else None
        
        speaker = pyttsx3.init()
        speaker.setProperty('rate', 150)
        speaker.setProperty('volume', 1.0)
        speaker.setProperty('voice', speaker.getProperty('voices')[gender].id)

        print("Current Speaking Rate: ", speaker.getProperty('rate'))
        print("Current Volume: ", speaker.getProperty('volume'))
        print("Current Voice: ", gen)

        for page in range(pdfReader.numPages):
            text =  pdfReader.getPage(page).extractText()
            # speaker.say(text)
            speaker.runAndWait()
        speaker.stop()

        speaker.save_to_file(text, filePath)
        speaker.runAndWait()

    except Exception as e:
        print("Exception: " + str(type(e)) +" "+ str(e))
        print("1. Check the File Extension.")
        print("2. Check the Directory you entered.")

pdf2audio(r'C:\Users\Swagato\Downloads\sample.pdf', "opp", "male",)


import os
import json

def json2csv(jsonPath, fileName = None):
    try:
        filePath = ""
        filePath = os.path.dirname(jsonPath)+"\\output.csv" if fileName == None else os.path.dirname(jsonPath)+ "\\" + fileName + ".csv"

        with open(jsonPath, 'r') as f:
            data = json.loads(f.read())

        output = ','.join([*data[0]])
        keys = output.split(",")

        for obj in data:
            if list(obj.keys()) != keys:
                raise ValueError("JSON does not contain same set of keys. Cannot convert to CSV")

        for obj in data:
            output += f'\n'
            for key in keys:
                output += f'{obj[key]},'
            output = output[:-1]

        with open(filePath, 'w') as f:
            f.write(output)

    except ValueError as v:
        print("Exception: " + str(type(v)) +" "+ str(v))
        print("1. Check the File Extension.")
        print("2. Check the Directory you entered.")
    except Exception as e:
        print("Exception: " + str(type(e)) +" "+ str(e))
        print("1. Check the File Extension.")
        print("2. Check the Directory you entered.")

json2csv(r"C:\Users\Swagato\Downloads\input.json", "op")


# This file contains package

from .ico2png import *
from .image2pdf import *
from .jpg2png import *
from .json2csv import *
from .pdf2audio import *
from .pdf2text import *
from .png2ico import *
from .png2jpeg import *


import PyPDF2
import os

def pdf2text(pdfPath, txtFileName = None):
    try:
        textPath = ""
        if txtFileName == None:
            textPath = os.path.normpath(pdfPath).replace(".pdf", "")+".txt"
        else:
            textPath = os.path.dirname(pdfPath)+"\\"+txtFileName+".txt"

        pdfobj = open(pdfPath, 'rb')
        pdfread = PyPDF2.PdfFileReader(pdfobj)

        pages, words = pdfread.numPages, 0
        
        for i in range(pages):
            pageObj = pdfread.getPage(i)
            with open(textPath, 'a+') as f: 
                f.write(pageObj.extractText() + "\n\n")
            for w in pageObj.extractText().split("\n"):
                words += len(w.split())
                            
        pdfobj.close()  
        print(f"Number of Pages: {pages}\nTotal Words: {words}")
    except Exception as e:
        print("Exception: " + str(type(e)) +" "+ str(e))
        print("1. Check the File Extension.")
        print("2. Check the Directory you entered.")



import os
import img2pdf

def image2pdf(imagePath, fileName = None):
    try:
        filePath = ""
        filePath = os.path.dirname(imagePath)+"\\output.pdf" if fileName == None else os.path.dirname(imagePath)+ "\\" + fileName + ".pdf"

        with open(filePath, "wb") as f:
            f.write(img2pdf.convert(imagePath))
                
    except Exception as e:
        print("Exception: " + str(type(e)) +" "+ str(e))
        print("1. Check the File Extension.")
        print("2. Check the Directory you entered.")


import os
import codecs
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))

VERSION = '0.0.1'
DESCRIPTION = 'Convert your file as you wish'
long_description = ''
with codecs.open(os.path.join(here, "README.txt"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

# Setting up
setup(
    name="sb_all_utility",
    version=VERSION,
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    url='',
    author="Swagato Bag",
    author_email="swagatobag23@gmail.com",
    license="MIT",
    packages=find_packages(),
    install_requires=['Pillow', 'img2pdf', 'PyPDF2', 'pyttsx3'],
    keywords=['python', 'file', 'jpg to png', 'png to jpg', 'pdf to text', 'pdf to audio', 'image to pdf', 'json to csv'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Education",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)